@@ -1,22 +1,26 @@
 # -*- coding: utf-8 -*-
-
+from __future__ import print_function
 from __future__ import unicode_literals
 
 import codecs
 
 from ..utils.tnt import TnT
+from .y09_2047 import CharacterBasedGenerativeModel
 
 
 class Seg(object):
 
-    def __init__(self):
-        self.segger = TnT()
+    def __init__(self, name='tnt'):
+        if name == 'tnt':
+            self.segger = TnT()
+        else:
+            self.segger = CharacterBasedGenerativeModel()
 
-    def save(self, fname):
-        self.segger.save(fname)
+    def save(self, fname, iszip=False):
+        self.segger.save(fname, iszip)
 
-    def load(self, fname):
-        self.segger.load(fname)
+    def load(self, fname, iszip=False):
+        self.segger.load(fname, iszip)
 
     def train(self, file_name):
         fr = codecs.open(file_name, 'r', 'utf-8')
@@ -34,16 +38,20 @@ class Seg(object):
         ret = self.segger.tag(sentence)
         tmp = ''
         for i in ret:
-            if i[1] == 's':
-                yield i[0]
-            elif i[1] == 'e':
+            if i[1] == 'e':
                 yield tmp+i[0]
                 tmp = ''
+            elif i[1] == 'b' or i[1] == 's':
+                if tmp:
+                    yield tmp
+                tmp = i[0]
             else:
                 tmp += i[0]
+        if tmp:
+            yield tmp
 
 
 if __name__ == '__main__':
     seg = Seg()
     seg.train('data.txt')
-    print ' '.join(seg.seg('主要是用来放置一些简单快速的中文分词和词性标注的程序'))
+    print(' '.join(seg.seg('主要是用来放置一些简单快速的中文分词和词性标注的程序')))
