@@ -8,7 +8,7 @@ class BM25(object):
 
     def __init__(self, docs):
         self.D = len(docs)
-        self.avgdl = sum(map(lambda x: len(x)+0.0, docs)) / self.D
+        self.avgdl = sum([len(doc)+0.0 for doc in docs]) / self.D
         self.docs = docs
         self.f = []
         self.df = {}
@@ -25,11 +25,11 @@ class BM25(object):
                     tmp[word] = 0
                 tmp[word] += 1
             self.f.append(tmp)
-            for k, v in tmp.iteritems():
+            for k, v in tmp.items():
                 if k not in self.df:
                     self.df[k] = 0
                 self.df[k] += 1
-        for k, v in self.df.iteritems():
+        for k, v in self.df.items():
             self.idf[k] = math.log(self.D-v+0.5)-math.log(v+0.5)
 
     def sim(self, doc, index):
@@ -37,8 +37,9 @@ class BM25(object):
         for word in doc:
             if word not in self.f[index]:
                 continue
+            d = len(self.docs[index])
             score += (self.idf[word]*self.f[index][word]*(self.k1+1)
-                      / (self.f[index][word]+self.k1*(1-self.b+self.b*self.D
+                      / (self.f[index][word]+self.k1*(1-self.b+self.b*d
                                                       / self.avgdl)))
         return score
 
